@@ -40,43 +40,40 @@ def create_copy_of_instance(instance, exclude=(), save_new=True, attrs=None):
     fields = instance.__class__._meta.concrete_fields
 
     if not isinstance(instance, models.Model):
-        raise ValueError(
-            'Invalid: Expected an instance of django.db.models.Model')
+        raise ValueError("Invalid: Expected an instance of django.db.models.Model")
 
     if not isinstance(attrs, dict):
         try:
             attrs = dict(attrs)
         except (TypeError, ValueError):
-            raise ValueError(
-                'Invalid: Expected attrs to be a dict or iterable.')
+            raise ValueError("Invalid: Expected attrs to be a dict or iterable.")
 
     for f in fields:
-        if all([
-            not f.auto_created,
-            f.concrete,
-            f.editable,
-            f not in instance.__class__._meta.related_objects,
-            f not in instance.__class__._meta.many_to_many,
-        ]):
+        if all(
+            [
+                not f.auto_created,
+                f.concrete,
+                f.editable,
+                f not in instance.__class__._meta.related_objects,
+                f not in instance.__class__._meta.many_to_many,
+            ]
+        ):
             defaults[f.attname] = getattr(instance, f.attname, f.get_default())
     defaults.update(attrs)
 
     new_obj = instance.__class__(**defaults)
 
     exclude = exclude or [
-        f.name for f in instance._meta.fields
-        if any([
-            f.name not in defaults,
-            f.has_default(),
-            f.null,
-        ])
+        f.name
+        for f in instance._meta.fields
+        if any([f.name not in defaults, f.has_default(), f.null])
     ]
 
     try:
         # Run the unique validation before creating the instance.
         new_obj.full_clean(exclude=exclude)
     except ValidationError as e:
-        raise ValidationError(', '.join(e.messages))
+        raise ValidationError(", ".join(e.messages))
 
     if save_new:
         new_obj.save()
@@ -86,7 +83,7 @@ def create_copy_of_instance(instance, exclude=(), save_new=True, attrs=None):
 
 def clean_value(value, suffix):
     # type: (str, str) -> str
-    return re.sub(r'{}\s[\d]$'.format(suffix), '', value, flags=re.I)
+    return re.sub(r"{}\s[\d]$".format(suffix), "", value, flags=re.I)
 
 
 @contextlib.contextmanager
@@ -115,14 +112,14 @@ def context_mutable_attribute(obj, key, value):
 
 
 def get_value(value, suffix, max_length, index):
-    duplicate_suffix = ' {} {}'.format(suffix, index)
+    duplicate_suffix = " {} {}".format(suffix, index)
     total_length = len(value + duplicate_suffix)
 
     if total_length > max_length:
         # Truncate the value to max_length - suffix length.
-        value = value[:max_length - len(duplicate_suffix)]
+        value = value[: max_length - len(duplicate_suffix)]
 
-    return '{}{}'.format(value, duplicate_suffix)
+    return "{}{}".format(value, duplicate_suffix)
 
 
 def generate_value(value, suffix, max_length, max_attempts):
@@ -132,8 +129,7 @@ def generate_value(value, suffix, max_length, max_attempts):
         yield get_value(value, suffix, max_length, i)
 
     raise StopIteration(
-        'CloneError: max unique attempts for {} exceeded ({})'
-        .format(value, max_attempts)
+        "CloneError: max unique attempts for {} exceeded ({})".format(value, max_attempts)
     )
 
 
